==> haskell-asn1-parse-0.9.5-322-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-3WY0cQhfKlvG9zsFLn2H1h
key:                  asn1-parse-0.9.5-3WY0cQhfKlvG9zsFLn2H1h
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  62b958811e5f23cdb1f958342724fea8
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-9.4.8/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/asn1-parse-0.9.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-parse
hs-libraries:         HSasn1-parse-0.9.5-3WY0cQhfKlvG9zsFLn2H1h
depends:
    asn1-encoding-0.9.6-7SEvJPexOIW3QeDcf1FbDq
    asn1-types-0.3.4-6LMHM6XounT3VTlG1gd4qg base-4.17.2.1
    bytestring-0.11.5.3

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.5-323-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-UHgwX49qZL9tsy2hCVty2
key:                  asn1-parse-0.9.5-UHgwX49qZL9tsy2hCVty2
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  c9dbda8371d4debbc05e10f1a02e6d19
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-9.4.8/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/asn1-parse-0.9.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-parse
hs-libraries:         HSasn1-parse-0.9.5-UHgwX49qZL9tsy2hCVty2
depends:
    asn1-encoding-0.9.6-CAwjlK8uWKv9dM99cgE2ve
    asn1-types-0.3.4-1FzZRhS4KrvH9STpZDYz6S base-4.17.2.1
    bytestring-0.11.5.3

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
